import {
  SaveStateI,
  wsTestDatabaseConnection,
  wsCreateState,
  wsUpdateState,
  useAuthCache,
  useAppDispatch,
} from '../../data-access';
import { useState } from 'react';
import { addSaveState, selectSaveState, testedSaveState } from '../../data-access/store/sessionSlice';
import { setSchemaLoading } from '../../data-access/store/schemaSlice';

export type ConnectionStatus = {
  updating: boolean;
  status: null | string;
  verified: boolean | null;
};

export const useHandleDatabase = () => {
  const dispatch = useAppDispatch();
  const [connectionStatus, setConnectionStatus] = useState<ConnectionStatus>({
    updating: false,
    status: null,
    verified: null,
  });

  const authCache = useAuthCache();

  async function submitDatabaseChange(
    saveStateData: SaveStateI,
    type: 'add' | 'update',
    forceAdd: boolean = false,
    concludedCallback: () => void,
  ): Promise<void> {
    console.log('submitDatabaseChange', saveStateData);
    setConnectionStatus(() => ({
      updating: true,
      status: 'Testing database connection',
      verified: null,
    }));

    wsTestDatabaseConnection(saveStateData.dbConnections?.[0], (data) => {
      if (!saveStateData) {
        console.error('formData is null');
        return;
      }
      if (saveStateData.userId !== authCache.authentication?.userID && authCache.authentication?.userID) {
        console.error('user_id is not equal to auth.userID');
        saveStateData.userId = authCache.authentication.userID;
      }
      if (data && data.status === 'success') {
        setConnectionStatus((prevState) => ({
          updating: false,
          status: 'Database connection verified',
          verified: true,
        }));
        dispatch(setSchemaLoading(true));
        dispatch(selectSaveState(undefined));
        if (type === 'add' || forceAdd) {
          wsCreateState(saveStateData, (newSaveState) => {
            dispatch(addSaveState(newSaveState));
            dispatch(testedSaveState(newSaveState.id));
            setConnectionStatus({
              updating: false,
              status: null,
              verified: null,
            });
            concludedCallback();
          });
        } else {
          if (data.saveStateID) {
            dispatch(testedSaveState(data.saveStateID));
          }
          wsUpdateState(saveStateData, (updatedSaveState) => {
            dispatch(addSaveState(updatedSaveState));
            setConnectionStatus({
              updating: false,
              status: null,
              verified: null,
            });
            concludedCallback();
          });
        }
      } else {
        setConnectionStatus((prevState) => ({
          updating: false,
          status: 'Database connection test failed',
          verified: false,
        }));
      }
    });
  }
  return { submitDatabaseChange, connectionStatus };
};
